/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.tools.ant.types;

import org.apache.tools.ant.BuildFileRule;
import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;

import static org.junit.Assert.assertEquals;

/**
 * JUnit 4 testcases for org.apache.tools.ant.types.FileSet.
 */

public class FileSetTest extends AbstractFileSetTest {

    @Rule
    public BuildFileRule buildRule = new BuildFileRule();

    @Before
    public void buildFileRuleSetUp() {
        buildRule.configureProject("src/etc/testcases/types/fileset.xml");
    }

    protected AbstractFileSet getInstance() {
        return new FileSet();
    }

    @Test
    public void testNoEncoding() {
        buildRule.executeTarget("no-encoding");
        assertEquals("/abc/fileset.xml", buildRule.getLog());
    }

    @Test
    public void testEncoding() {
        buildRule.executeTarget("encoding");
        assertEquals("/abc/fileset.xml", buildRule.getLog());
    }

}
